Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(125)

Unified Diff: chrome/browser/storage_monitor/storage_monitor_chromeos.h

Issue 12382005: Rename RemovableDeviceNotifications=>StorageMonitor (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Fix some includes from recent merge. Created 7 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/storage_monitor/storage_monitor_chromeos.h
diff --git a/chrome/browser/storage_monitor/removable_device_notifications_chromeos.h b/chrome/browser/storage_monitor/storage_monitor_chromeos.h
similarity index 89%
rename from chrome/browser/storage_monitor/removable_device_notifications_chromeos.h
rename to chrome/browser/storage_monitor/storage_monitor_chromeos.h
index be745499bc268a9916ffc98c6ec66693e2914d1e..81f916825b80c83044f149712d48550238bc7d79 100644
--- a/chrome/browser/storage_monitor/removable_device_notifications_chromeos.h
+++ b/chrome/browser/storage_monitor/storage_monitor_chromeos.h
@@ -2,7 +2,7 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
// chromeos::RemovableDeviceNotificationsCros listens for mount point changes
// and notifies listeners about the addition and deletion of media
// devices.
@@ -24,13 +24,13 @@
namespace chromeos {
-class RemovableDeviceNotificationsCros
+class StorageMonitorCros
: public chrome::StorageMonitor,
- public base::RefCountedThreadSafe<RemovableDeviceNotificationsCros>,
+ public base::RefCountedThreadSafe<StorageMonitorCros>,
public disks::DiskMountManager::Observer {
public:
// Should only be called by browser start up code. Use GetInstance() instead.
- RemovableDeviceNotificationsCros();
+ StorageMonitorCros();
virtual void OnDiskEvent(disks::DiskMountManager::DiskEvent event,
const disks::DiskMountManager::Disk* disk) OVERRIDE;
@@ -63,13 +63,13 @@ class RemovableDeviceNotificationsCros
uint64 storage_size_in_bytes;
};
- friend class base::RefCountedThreadSafe<RemovableDeviceNotificationsCros>;
+ friend class base::RefCountedThreadSafe<StorageMonitorCros>;
// Mapping of mount path to removable mass storage info.
typedef std::map<std::string, StorageObjectInfo> MountMap;
// Private to avoid code deleting the object.
- virtual ~RemovableDeviceNotificationsCros();
+ virtual ~StorageMonitorCros();
// Checks existing mount points map for media devices. For each mount point,
// call CheckMountedPathOnFileThread() below.
@@ -91,7 +91,7 @@ class RemovableDeviceNotificationsCros
// Only accessed on the UI thread.
MountMap mount_map_;
- DISALLOW_COPY_AND_ASSIGN(RemovableDeviceNotificationsCros);
+ DISALLOW_COPY_AND_ASSIGN(StorageMonitorCros);
};
} // namespace chromeos
@@ -2,7 +2,7 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-// chromeos::RemovableDeviceNotificationsCros listens for mount point changes
+// chromeos::StorageMonitorCros listens for mount point changes
// and notifies listeners about the addition and deletion of media
// devices.

Powered by Google App Engine
This is Rietveld 408576698